@@ -4,11 +4,12 @@ import multiprocessing as mp
 
 from .equity_curves import *
 from .signals import *
+from .aggregate import *
 
 def generate_filepath(py_filename, output_folder, start_date, end_date, para_dict, para_combination):
     start_date_str = datetime.datetime.strptime(start_date, '%Y-%m-%d').strftime("%Y%m%d")
     end_date_str = datetime.datetime.strptime(end_date, '%Y-%m-%d').strftime("%Y%m%d")
-    save_name = f'file={py_filename}&date={start_date_str}{end_date_str}'
+    save_name = f'file={py_filename}&date={start_date_str}{end_date_str}&'
 
     for i, key in enumerate(para_dict):
         para = para_combination[i]
@@ -79,6 +80,12 @@ def plot_signal_analysis(py_filename, output_folder, start_date, end_date, para_
 
     return app
 
+def plot_aggregate():
+
+    app = aggregate.Aggregate()
+
+    return app
+
 
 def cal_performance(save_path, start_date, end_date):
     result_dict = {}
