@@ -2,6 +2,7 @@ import pandas as pd
 import numpy as np
 import datetime
 import math
+import os
 
 from dash import dcc, html    ## pip install dash
 import dash_bootstrap_components as dbc
@@ -244,7 +245,8 @@ class Components:
             df['bah_mdd_pct'] = "{:.0%}".format(df['bah_mdd_pct'] / 100)
             df['bah_return'] = "{:.0%}".format(df['bah_return'] / 100)
             df['bah_annualized_return'] = "{:.0%}".format(df['bah_annualized_return'] / 100)
-            df['bah_annualized_std'] = "{:.2%}".format(df['bah_annualized_std'] / 100)
+            df['bah_annualized_std'] = "{:.0%}".format(df['bah_annualized_std'] / 100)
+            # df['bah_annualized_sr'] = round(df['bah_annualized_sr'], 1)
         except Exception as e:
             # print(e)
             pass
@@ -313,32 +315,51 @@ class Components:
         matrix_div = html.Div([
             html.Div(style={'height': '8px', }),
 
-            dbc.Row([
-                dbc.Col(html.Div('Selected', style={'color': 'Cyan', 'font-size': '15px'}), width=4),
-                # dbc.Col(html.Div('Save', id='save',
-                #                  style={'font-size': '15px','cursor': 'pointer',
-                #                         'text-align': 'center', 'border-radius': '5px',
-                #                         'background-color': 'Yellow', 'color':'black',
-                #                         }), width=4),
-                # dbc.Col(html.Div('List All', id="open",
-                #                  style={'font-size': '15px','cursor': 'pointer',
-                #                         'text-align': 'center', 'border-radius': '5px',
-                #                         'background-color': 'Yellow', 'color':'black',
-                #                         }), width=4),
-            ], style={'padding-right': '20px'}),
+            html.Div([
+                html.Div('Selected Curve', style={'color': 'Cyan',
+                                                  'display': 'inline',
+                                                  'font-size': '15px'}),
+                html.Div('', id='save_status',
+                         style={'color': 'Cyan',
+                                'display': 'inline',
+                                'padding-left': '5px',
+                                'font-size': '15px'}),
+            ]),
 
-            dbc.Modal(
-                [
-                    # dbc.ModalHeader("HEADER"),
-                    dbc.ModalBody("List of Saved Strategies here"),
-                    dbc.ModalBody(html.Div('Close', id="close", style={'font-size': '15px', 'cursor': 'pointer'})),
+            #
+            # dbc.Row([
+            #     dbc.Col(html.Div('Selected Curve', style={'color': 'Cyan', 'font-size': '15px'}), width=7),
+            #     dbc.Col(html.Div('--', id='save_status',
+            #                      style={'color': 'Grey',
+            #                             'padding-left': '5px',
+            #                             'font-size': '15px'}),
+            #             width=4),
+            #     # dbc.Col(html.Div('--', id='save',
+            #     #                  style={'font-size': '15px',
+            #     #                         'text-align': 'center', 'border-radius': '5px',
+            #     #                         'background-color': 'Grey', 'color':'black',
+            #     #                         }), width=5),
+            #     # dbc.Col(html.Div('List All', id="open",
+            #     #                  style={'font-size': '15px','cursor': 'pointer',
+            #     #                         'text-align': 'center', 'border-radius': '5px',
+            #     #                         'background-color': 'Yellow', 'color':'black',
+            #     #                         }), width=4),
+            # ], style={'padding-right': '20px'}),
 
-                    # dbc.ModalFooter(
-                    #     dbc.Button("CLOSE BUTTON", id="close", className="ml-auto")
-                    # ),
-                ],
-                id="modal",
-            ),
+            # dbc.Modal(
+            #     [
+            #         # dbc.ModalHeader("HEADER"),
+            #         dbc.ModalBody("List of Saved Strategies here"),
+            #         dbc.ModalBody(html.Div('Close', id="close", style={'font-size': '15px', 'cursor': 'pointer'})),
+            #
+            #         # dbc.ModalFooter(
+            #         #     dbc.Button("CLOSE BUTTON", id="close", className="ml-auto")
+            #         # ),
+            #     ],
+            #     id="modal",
+            # ),
+
+            # html.Div(style={'height': '5px', }),
 
             dbc.Row(html.Div(title), style={'font-size': '11px'}),
 
@@ -354,7 +375,15 @@ class Components:
 
             html.Div('Performance by Year', style={'color': 'Cyan', 'font-size': '15px'}),
             html.Div(style={'height': '5px', }),
-            html.Div(children=year_col1, style={'font-size': '11px'})
+            html.Div(children=year_col1, style={'font-size': '11px'}),
+            html.Div(style={'height': '20px'}),
+
+            html.Div([
+                html.Div(style={'height': '5px'}),
+                html.Div('', id='save_string'),
+                html.Div(style={'height': '5px'}),
+            ], id='save_button'),
+
         ],style={'padding': '0px',})
 
         return matrix_div
@@ -752,6 +781,20 @@ class Components:
         return fig_pct, fig_rise, fig_fall
 
 
+    def path_to_dict(self,path):
+        filename = path.split('/')[-1].split('.csv')[0]
+        parameters = {}
+        for element in filename.split('&'):
+            key, content = element.split('=')
+            if key == 'date':
+                # parameters['date'] = f'{content[:8]} - {content[8:]}'
+                parameters['startdate'], parameters['enddate'] = content[:8], content[8:]
+            else:
+                parameters[key] = content
+
+        return parameters
+
+
     def generate_df_stat(self, df, period):
         col_pct = 'pct_change_' + str(period)
         col_rise = 'max_rise_' + str(period)
@@ -772,4 +815,109 @@ class Components:
         df_his[col_rise] = df_his[col_rise].map(lambda x: round(x, 2))
         df_his[col_fall] = df_his[col_fall].map(lambda x: round(x, 2))
 
-        return round(df_his[col_pct].mean(), 2), round(df_his[col_rise].mean(), 2), round(df_his[col_fall].mean(), 2)
\ No newline at end of file
+        return round(df_his[col_pct].mean(), 2), round(df_his[col_rise].mean(), 2), round(df_his[col_fall].mean(), 2)
+
+
+    def aggregate_df(self):
+        folders = []
+        for filename in os.listdir():
+            if os.path.isfile(f'{filename}/saved_strategies.csv'):
+                folders.append(filename)
+        folders.sort()
+
+        equity_curves = []
+        for folder in folders:
+            df_saved = pd.read_csv(f'{folder}/saved_strategies.csv')
+            for i, row in df_saved.iterrows():
+                equity_path = f'{folder}/{row["path"]}'
+                parameters = self.path_to_dict(equity_path)
+                dict = {}
+                dict['folder'] = folder
+                dict['py'] = parameters['file']
+                dict['path'] = equity_path
+                dict['parameters'] = parameters
+                equity_curves.append(dict)
+
+        line_colour = []
+        for c in range(len(equity_curves)):
+            profile = c % 6
+            degree = (c // 6) / math.ceil(len(equity_curves) / 6)
+            line_colour.append(self.assign_colour(profile, degree))
+
+        df = pd.DataFrame.from_dict(equity_curves, orient='columns', dtype=None, columns=None)
+        df['line_colour'] = line_colour
+        df.index += 1
+
+        choices = []
+        for i in list(df.index):
+            line_height = '120%'
+            text = []
+            for key, value in df.iloc[i - 1].parameters.items():
+                if not key == 'file':
+                    text.append(html.Div(f'{key} : {value}',style={'line-height': line_height}))
+            choices.append({
+                "label": html.Div([
+
+                    html.Div('----------------------------------------------------------------------------------'),
+
+                    dbc.Row([
+                        dbc.Col([html.Div('Curve', style={'line-height': line_height})],
+                                width=3),
+                        dbc.Col([html.Div(str(i).zfill(3), style={'line-height': line_height})],
+                                width=6),
+                    ]),
+
+                    html.Div(style={'height': '5px'}),
+
+                    dbc.Row([
+                        dbc.Col([html.Div('folder',style={'line-height':line_height})],
+                                width=3),
+                        dbc.Col([html.Div(df.iloc[i - 1].folder,style={'line-height':line_height})],
+                                width=6),
+                    ]),
+
+                    html.Div(style={'height': '5px'}),
+
+                    dbc.Row([
+                        dbc.Col([html.Div('.py',style={'line-height':line_height})],
+                                width=3),
+                        dbc.Col([html.Div(df.iloc[i - 1].py,style={'line-height':line_height})],
+                                width=6),
+                    ]),
+
+                    html.Div(style={'height': '5px'}),
+
+                    dbc.Row([
+                        dbc.Col([html.Div('parameters',style={'line-height':line_height})],
+                                width=3),
+                        dbc.Col([html.Div(text,style={'line-height':line_height})],
+                                width=6),
+                    ]),
+
+                ],style={"display": "inline-block", 'width':'400px'}
+
+                ),
+
+                "value": i,
+            })
+
+        _checklist = html.Div([
+            dcc.Checklist(
+                options=choices,
+                id='curve_checklist',
+                value=list(df.index),
+                inputStyle={'margin-left': '3px', 'margin-right': '10px',
+                               'background-color': 'red',
+                               'vertical-align': 'top', 'position': 'relative',
+                               'top': '1.6em'}
+            )],
+
+        ),
+
+        row = html.Div(
+            dbc.Row([
+                html.Div(_checklist),
+                html.Div(style={'height': '5px'}),
+            ]), style={'padding': '0px', 'font-size': '12px'})
+
+        return df, row
\ No newline at end of file
