@@ -14,11 +14,17 @@ class Plot:
     add_button_count = 0
     chart1_button_clicks = 0
     chart2_button_clicks = 0
+    save_clicks = 0
     line_selected = -1
     button_list = (0, 1, 2, 3, 4, 5, 6, 7, 8, 9)
     chart_type = 1
     relayoutData = []
     init = True
+    save_path = ''
+    initial_capital = 0
+    return_in_capital = 0
+    mdd = 0
+    sharp = 0
 
 
     def __new__(self, filename, output_folder, start_date, end_date, para_dict, result_df, generate_filepath, settings):
@@ -61,8 +67,6 @@ class Plot:
                         html.Div('Parameters', style={'color': 'Cyan', 'margin-left': '15px', 'font-size': '15px'}),
                         html.Div(id='checklist-container',children=checkbox_div),
                         html.Div(style={'height': '10px', }),
-                        # html.Div('--------------------------------------',style={'margin-left': '15px'}),
-                        # html.Div('Filters for:', style={'font-size': '15px', 'margin-left': '15px'}),
                         html.Div('Filters for', style={'color': 'Cyan', 'margin-left': '15px', 'font-size': '15px'}),
                         html.Div(style={'height': '10px', }),
                         html.Div(id='filter', children=filter_div,style={'padding': '0px 20px',
@@ -82,8 +86,8 @@ class Plot:
 
                     # Middle Column
                     dbc.Col(html.Div([
-                        html.Div(id='performance_matrix', children=performance_matrix ),
 
+                        html.Div(id='performance_matrix', children=performance_matrix ),
 
                     ], style={'padding': '5px',})
                         , style={'padding': '0', }, width=2),
@@ -152,8 +156,12 @@ class Plot:
             chart1_button_text = ''
             chart2_button_text = ''
 
+            chart1_button_click = False
+
+
             if chart1_button_clicks:
                 if chart1_button_clicks > self.chart1_button_clicks:
+                    chart1_button_click = True
                     self.chart1_button_clicks = chart1_button_clicks
                     self. chart_type = 1
                     hist_style = {'display': 'none'}
@@ -171,9 +179,10 @@ class Plot:
                             para_values = []
                             for key in para_key_list:
                                 para_values.append(self.graph_df.iloc[self.line_selected][key])
-                            save_path = generate_filepath(filename, output_folder, start_date, end_date, para_dict,
-                                                          para_values)
+                            # save_path = generate_filepath(filename, output_folder, start_date, end_date, para_dict,
+                            #                               para_values)
                             line_colour = self.graph_df.iloc[self.line_selected].line_colour
+                            save_path = self.save_path
                             df = pd.read_csv(save_path)
                             df_chart = components.prepare_df_chart(df)
 
@@ -231,20 +240,29 @@ class Plot:
 
             ## Initialize After Refresh
             if not self.init:
-               if (not sort_method) and (not add_button_clicks):
-                   self.sort_method_current = sort_method
-                   self.filter_list = []
-                   self.add_button_count = 0
-                   self.chart2_button_clicks = 0
-                   self.line_selected = -1
-                   self.chart_type = 1
-                   hist_area = []
-                   hist_style = {'display': 'none'}
-                   self.init = True
-                   filter_dropdown_div = filter_dropdown
-                   filter_input_div = filter_input
-                   return fig_line, filter_div, filter_dropdown_div,filter_input_div,_add_button_style, \
-                          None, chart1_button_text, chart2_button_text, hist_area, hist_style
+                if not add_button_clicks:
+                    if not chart1_button_click:
+                        self.sort_method_current = sort_method
+                        self.filter_list = []
+                        self.add_button_count = 0
+                        self.chart2_button_clicks = 0
+                        self.save_clicks = 0
+                        self.chart_type = 1
+                        hist_area = []
+                        hist_style = {'display': 'none'}
+                        self.init = True
+                        filter_dropdown_div = filter_dropdown
+                        filter_input_div = filter_input
+
+                   # if not chart1_button_click:
+                   #     print('No!!!')
+                   #     self.line_selected = -1
+                   # self.chart_type = 1
+                   # hist_area = []
+                   # hist_style = {'display': 'none'}
+                   # self.init = True
+                   # filter_dropdown_div = filter_dropdown
+                   # filter_input_div = filter_input
 
 
             ## Add Button Pressed
@@ -270,6 +288,7 @@ class Plot:
             else:
                 self.add_button_count = 0  # Necessary for initialization
 
+
             # Filter delete button pressed, remove one filter
             for i in range(len(vals)):
                 if not vals[i] == self.button_list[i]:
@@ -284,6 +303,7 @@ class Plot:
                         _add_button_style = add_button_style
                     break
 
+
             # Sort Method Selected, generate Chart 1
             if sort_method:
                 current_df = result_df.copy()
@@ -351,6 +371,7 @@ class Plot:
         )
         def update_matrix(clickData,performance_matrix):
             button_style = {'text-align': 'right','color':'grey','font-size':'14px'}
+            self.init = False
             if clickData:
                 if self.chart_type == 1:
                     i = clickData['points'][0]['curveNumber'] - 1
@@ -358,49 +379,133 @@ class Plot:
                                                                               self.graph_df.iloc[i].copy(), para_dict)
                     self.line_selected = i
                     button_style = {'text-align': 'right','cursor': 'pointer','font-size':'14px'}
+
+                    para_key_list = list(para_dict)
+                    para_values = []
+                    for key in para_key_list:
+                        para_values.append(self.graph_df.iloc[self.line_selected][key])
+                    save_path = generate_filepath(filename, output_folder, start_date, end_date, para_dict,
+                                                  para_values)
+
+                    self.save_clicks = 0 # Needed for save button click tracking
+
+                    df = self.graph_df.iloc[i].copy()
+                    self.save_path = save_path
+                    self.initial_capital = pd.read_csv(save_path).iloc[0].equity_value
+                    self.return_in_capital = df['return_on_capital']
+                    self.mdd = df['mdd_pct']
+                    self.sharp = df['annualized_sr']
+
+
             return performance_matrix, button_style
 
 
-        # Model
-        @app.callback(
-            Output("modal", "is_open"),
-            [Input("open", "n_clicks"), Input("close", "n_clicks")],
-            [State("modal", "is_open")],
-        )
-        def toggle_modal(n1, n2, is_open):
-            # print('Modal!')
-            if n1 or n2:
-                return not is_open
-            else:
-                pass
-                # print('No Modal Click')
-            return is_open
+        # # Model
+        # @app.callback(
+        #     Output("modal", "is_open"),
+        #     [Input("open", "n_clicks"), Input("close", "n_clicks")],
+        #     [State("modal", "is_open")],
+        # )
+        # def toggle_modal(n1, n2, is_open):
+        #     # print('Modal!')
+        #     if n1 or n2:
+        #         return not is_open
+        #     else:
+        #         pass
+        #         # print('No Modal Click')
+        #     return is_open
+
 
         # Save Button
-        # @app.callback(
-        #     Output('save', "style"),
-        #     Input('save', "n_clicks"),
-        #     State('save', "style"),
-        # )
-        # def save(save_click, save_style):
-        #     print(output_folder)
-        #     # print('Saved!')
-        #     if not os.path.isfile('saved_strategies.csv'):
-        #         print('No File!!!!')
-        #         saved_df = pd.DataFrame(columns=['parameters','start_date','end_date' ])
-        #         print(saved_df)
-        #
-        #     else:
-        #         pass
-        #         print('File Here !!!')
-        #     if save_click:
-        #         pass
-        #         # print(save_click)
-        #     else:
-        #         pass
-        #         # print('No Save Click')
-        #
-        #     return save_style
+        @app.callback(
+            Output('save_status', "children"),
+            Output('save_string', "children"),
+            Output('save_button', "style"),
+            Input('save_status', "children"),
+            Input('save_button', "n_clicks"),
+            State('save_string', "children"),
+        )
+        def save_button(save_status, save_clicks, button_string):
+            if not os.path.isfile('saved_strategies.csv'):
+                pd.DataFrame(columns=['path','initial','return','mdd','sharp']).to_csv('saved_strategies.csv', index=False)
+            else:
+                pass
+
+            button_available = None
+            save_status = ''
+            button_string = ''
+            button_style = {}
+
+            # Process until first line selected
+            # save_path = self.save_path
+            # if self.init:
+            #     save_status = ''
+            #     button_string = ''
+            #     button_style = {}
+            # print('Trigger!',self.line_selected)
+
+            save_path = self.save_path
+            if not self.init:
+                if not save_clicks: #
+
+                    save_status = ''
+                    button_string = '--'
+                    button_style = {'font-size': '15px', 'margin-left': '20px', 'margin-right': '30px',
+                                    'text-align': 'center', 'border-radius': '5px',
+                                    'background-color': 'Grey', 'color': 'black',
+                                    }
+
+                    if self.line_selected > -1:
+                        saved_df = pd.read_csv('saved_strategies.csv')
+                        if not save_path in list(saved_df['path']):
+                            button_available = True
+                        else:
+                            button_available = False
+
+
+                else:
+                    if save_clicks > self.save_clicks:
+                        self.save_clicks = save_clicks
+
+                        if self.line_selected > -1:
+                            saved_df = pd.read_csv('saved_strategies.csv')
+
+                            if not save_path in list(saved_df['path']):
+                                saved_df = pd.concat([saved_df, pd.DataFrame({'path': save_path,
+                                                                              'initial': self.initial_capital,
+                                                                              'return': self.return_in_capital,
+                                                                              'mdd': self.mdd,
+                                                                              'sharp': self.sharp,
+                                                                              },index={10})],
+                                                     ignore_index=True)
+                                button_available = False
+                            else:
+                                index = saved_df.index[saved_df['path'] == save_path].tolist()
+                                saved_df = saved_df.drop(index=index)
+                                button_available = True
+
+                            saved_df.to_csv('saved_strategies.csv', index=False)
+
+            if button_available is not None:
+                if button_available:
+                    save_status = ''
+                    button_string = 'Save Curve'
+                    button_style = {'font-size': '15px', 'margin-left': '20px', 'margin-right': '30px',
+                                    'text-align': 'center', 'border-radius': '5px', 'cursor': 'pointer',
+                                    'background-color': 'Yellow', 'color': 'black',
+                                    }
+                else:
+                    save_status = '( Saved )'
+                    button_string = 'Unsave Curve'
+                    button_style = {'font-size': '15px', 'margin-left': '20px', 'margin-right': '30px',
+                                    'text-align': 'center', 'border-radius': '5px', 'cursor': 'pointer',
+                                    'background-color': 'Magenta', 'color': 'white',
+                                    }
+
+
+
+            return save_status, button_string, button_style
+
 
 
         return app
\ No newline at end of file
